%define mainver %(echo %{version} | sed -e 's/\\([0-9]*\\.[0-9]*\\)\\.[0-9]*/\\1/')
# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python2_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so

%define module  Twisted

Name:           python-twisted
Version:        17.5.0
Release:        %mkrel 1
Summary:        Event-based framework for internet applications
License:        MIT
Group:          Development/Python
URL:            http://www.twistedmatrix.com/
Source0:        https://files.pythonhosted.org/packages/source/T/%{module}/%{module}-%{version}.tar.bz2
BuildRequires:  pkgconfig(python2)
BuildRequires:  pythonegg(2)(incremental)
BuildRequires:  pythonegg(2)(setuptools)
BuildRequires:  pythonegg(2)(zope.interface)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pythonegg(3)(incremental)
BuildRequires:  pythonegg(3)(setuptools)
BuildRequires:  pythonegg(3)(zope.interface)

Requires:       pythonegg(2)(pycrypto)
Requires:       pythonegg(2)(pyopenssl)
Requires:       pythonegg(2)(zope.interface)
Requires:       pythonegg(2)(pygobject)
# python-twisted-core
Requires:       pythonegg(2)(pyserial)
# python-twisted-conch
Requires:       pythonegg(2)(pyasn1)

# Bring all provided resources back into the main package namespace.
Obsoletes:      python-twisted-conch < 15.2.1-2
Provides:       python-twisted-conch = %{version}-%{release}
Obsoletes:      python-twisted-core < 15.2.1-2
Provides:       python-twisted-core = %{version}-%{release}
Obsoletes:      python-twisted-lore < 15.2.1-2
Provides:       python-twisted-lore = %{version}-%{release}
Obsoletes:      python-twisted-mail < 15.2.1-2
Provides:       python-twisted-mail = %{version}-%{release}
Obsoletes:      python-twisted-names < 15.2.1-2
Provides:       python-twisted-names = %{version}-%{release}
Obsoletes:      python-twisted-news < 15.2.1-2
Provides:       python-twisted-news = %{version}-%{release}
Obsoletes:      python-twisted-pair < 15.2.1-2
Provides:       python-twisted-pair = %{version}-%{release}
Obsoletes:      python-twisted-runner < 15.2.1-2
Provides:       python-twisted-runner = %{version}-%{release}
Obsoletes:      python-twisted-web < 15.2.1-2
Provides:       python-twisted-web = %{version}-%{release}
Obsoletes:      python-twisted-words < 15.2.1-2
Provides:       python-twisted-words = %{version}-%{release}

%description
Twisted is a framework, written in Python, for writing networked
applications. It includes implementations of a number of commonly used
network services such as a web server, an IRC chat server, a mail
server, a relational database interface and an object broker. Developers
can build applications using all of these services as well as custom
services that they write themselves. Twisted also includes a user
authentication system that controls access to services and provides
services with user context information to implement their own security
models.


%package -n python3-twisted
Summary:        Python3 event-based framework for internet applications
Group:          Development/Python
Requires:       pythonegg(3)(pycrypto)
Requires:       pythonegg(3)(pyopenssl)
Requires:       pythonegg(3)(zope.interface)
Requires:       pythonegg(3)(pygobject)
Requires:       pythonegg(3)(pyserial)
Requires:       pythonegg(3)(pyasn1)

%description -n python3-twisted
Twisted is a framework, written in Python3, for writing networked
applications. It includes implementations of a number of commonly used
network services such as a web server, an IRC chat server, a mail
server, a relational database interface and an object broker. Developers
can build applications using all of these services as well as custom
services that they write themselves. Twisted also includes a user
authentication system that controls access to services and provides
services with user context information to implement their own security
models.


%prep
%autosetup -n %{module}-%{version}

cp -a . %{py3dir}


%build
%py2_build

pushd %{py3dir}
%py3_build
popd


%install
pushd %{py3dir}
%py3_install
# twisted in python 3 supports only few command line tools for now.
# Let's rename the tools the other way round after the python 3 version supports all.
for name in cftp ckeygen conch pyhtmlizer tkconch trial twist twistd; do
  mv "%{buildroot}%{_bindir}/$name"{,3}
done
popd
%py2_install

# no need for c and h source code
find %{buildroot}%{python2_sitearch}/twisted -name '*.c' -delete
find %{buildroot}%{python2_sitearch}/twisted -name '*.h' -delete
find %{buildroot}%{python3_sitearch}/twisted -name '*.c' -delete
find %{buildroot}%{python3_sitearch}/twisted -name '*.h' -delete

# pem-certificate
find %{buildroot}%{python2_sitearch}/twisted -name '*.pem' -delete
find %{buildroot}%{python3_sitearch}/twisted -name '*.pem' -delete

# non-executable-script
chmod +x %{buildroot}%{python2_sitearch}/twisted/mail/test/pop3testserver.py
chmod +x %{buildroot}%{python2_sitearch}/twisted/trial/test/scripttest.py
chmod +x %{buildroot}%{python3_sitearch}/twisted/trial/test/scripttest.py

# no-manual-page-for-binary
mkdir -p %{buildroot}%{_mandir}/man1/
for s in conch core mail; do
  cp -pr docs/$s/man/*.1 %{buildroot}%{_mandir}/man1/
done

%files
%doc CONTRIBUTING NEWS.rst README.rst docs/*
%license LICENSE
%{_bindir}/cftp
%{_bindir}/ckeygen
%{_bindir}/conch
%{_bindir}/mailmail
%{_bindir}/pyhtmlizer
%{_bindir}/tkconch
%{_bindir}/trial
%{_bindir}/twist
%{_bindir}/twistd
%{python2_sitearch}/twisted/
%{python2_sitearch}/%{module}-%{version}-py%{python2_version}.egg-info/
%{_mandir}/man1/*.1.*


%files -n python3-twisted
%doc CONTRIBUTING NEWS.rst README.rst docs/*
%license LICENSE
%{_bindir}/cftp3
%{_bindir}/ckeygen3
%{_bindir}/conch3
%{_bindir}/pyhtmlizer3
%{_bindir}/tkconch3
%{_bindir}/trial3
%{_bindir}/twist3
%{_bindir}/twistd3
%{python3_sitearch}/twisted/
%{python3_sitearch}/%{module}-%{version}-py%{python3_version}.egg-info/
%{_mandir}/man1/*.1.*



%changelog
* Tue Feb 20 2018 daviddavid <daviddavid> 17.5.0-1.mga6
+ Revision: 1203449
- new version: 17.5.0 (needed for kajongg)
- python3-twisted subpackage is no more a noarch package

* Sat Aug 20 2016 philippem <philippem> 16.3.2-1.mga6
+ Revision: 1047146
- update to 16.3.2

* Thu May 19 2016 philippem <philippem> 16.2.0-1.mga6
+ Revision: 1016881
- update to 16.2.0

* Mon Apr 25 2016 philippem <philippem> 16.1.1-1.mga6
+ Revision: 1006100
- update to 16.1.1

* Mon Apr 04 2016 philippem <philippem> 16.1.0-1.mga6
+ Revision: 998390
- set python3 as noarch
- fix some files for Python3
- update to 16.1.0 - add Python3 version

* Wed Mar 16 2016 philippem <philippem> 16.0.0-1.mga6
+ Revision: 992150
- update to 16.0.0

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Mon Nov 30 2015 daviddavid <daviddavid> 15.5.0-1.mga6
+ Revision: 907276
- new version: 15.5.0

* Wed Oct 07 2015 daviddavid <daviddavid> 15.4.0-2.mga6
+ Revision: 886879
- fix python2 macro

* Fri Sep 18 2015 daviddavid <daviddavid> 15.4.0-1.mga6
+ Revision: 880293
- new version: 15.4.0
- ship Twisted as a fully featured package without subpackages on the advice
- use new python macros
- introduce license macro

* Mon Jun 22 2015 daviddavid <daviddavid> 15.2.1-1.mga6
+ Revision: 839072
- new version: 15.2.1

* Wed Oct 15 2014 umeabot <umeabot> 14.0.0-4.mga5
+ Revision: 742469
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 14.0.0-3.mga5
+ Revision: 729889
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 14.0.0-2.mga5
+ Revision: 688387
- Mageia 5 Mass Rebuild

* Sat Jun 07 2014 daviddavid <daviddavid> 14.0.0-1.mga5
+ Revision: 634568
- add new required package on python-twisted-pair

  + philippem <philippem>
    - update to 14.0.0, remove pythonegg(3) provides

* Mon Mar 31 2014 kharec <kharec> 13.2.0-1.mga5
+ Revision: 610801
- version 13.2.0

* Tue Oct 22 2013 neoclust <neoclust> 13.1.0-4.mga4
+ Revision: 546302
- Add missing provides

* Tue Oct 22 2013 umeabot <umeabot> 13.1.0-3.mga4
+ Revision: 544363
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 13.1.0-2.mga4
+ Revision: 499580
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Oct 05 2013 philippem <philippem> 13.1.0-1.mga4
+ Revision: 491851
- Update to 13.1.0

* Sun Jan 13 2013 umeabot <umeabot> 12.2.0-2.mga3
+ Revision: 379586
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Sep 20 2012 philippem <philippem> 12.2.0-1.mga3
+ Revision: 296404
- Update to 12.2.0

  + guillomovitch <guillomovitch>
    - spec cleanup
    - rename distribution-specific documentation file to README.mga

* Wed Nov 23 2011 philippem <philippem> 11.1.0-1.mga2
+ Revision: 171272
- Update to 11.1.0

* Sun Jun 19 2011 kharec <kharec> 11.0.0-1.mga2
+ Revision: 110004
- new version 11.0.0

* Tue Mar 29 2011 ahmad <ahmad> 10.2.0-2.mga1
+ Revision: 78952
- add the pythonegg provides manually as this is a meta package, so the rpm
  pythonegg auto-provides scripts won't work here

* Mon Feb 21 2011 ahmad <ahmad> 10.2.0-1.mga1
+ Revision: 55818
- update to 10.2.0

* Wed Jan 19 2011 erwan <erwan> 10.1.0-2.mga1
+ Revision: 24864
- imported package python-twisted


* Tue Nov 02 2010 Crispin Boylan <crisb@mandriva.org> 10.1.0-2mdv2011.0
+ Revision: 591994
- Rebuild

* Tue Jul 20 2010 Lev Givon <lev@mandriva.org> 10.1.0-1mdv2011.0
+ Revision: 555027
- Update to 10.1.0.

* Thu Mar 04 2010 Lev Givon <lev@mandriva.org> 10.0.0-1mdv2010.1
+ Revision: 514219
- Update to 10.0.0.

* Sat Jan 02 2010 Frederik Himpe <fhimpe@mandriva.org> 9.0.0-1mdv2010.1
+ Revision: 485334
- update to new version 9.0.0

* Sat Jan 03 2009 Jérôme Soyer <saispo@mandriva.org> 8.2.0-1mdv2009.1
+ Revision: 323864
- New upstream release

* Fri Jun 13 2008 Michael Scherer <misc@mandriva.org> 8.1.0-1mdv2009.0
+ Revision: 219002
- update to 8.1.0

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Aug 31 2007 Crispin Boylan <crisb@mandriva.org> 2.5.0-1mdv2008.0
+ Revision: 76791
- Update version, remove deprecated modules twisted,flow and xish

* Thu Jul 26 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.4.0-1mdv2008.0
+ Revision: 55867
- update to new version 2.4.0


* Mon Aug 22 2005 Frederic Crozat <fcrozat@mandriva.com> 2.0.0-3mdk
- Remove dependency on non existing package

* Sun May 15 2005 Michael Scherer <misc@mandriva.org> 2.0.0-2mdk
- empty pacakge cannot be uploaded, add a doc

* Sun May 15 2005 Michael Scherer <misc@mandriva.org> 2.0.0-1mdk
- package splitted upstream, so empty this one
- update license

* Sat Dec 04 2004 Michael Scherer <misc@mandrake.org> 1.3.0-4mdk
- Rebuild for new python

* Sun Nov 14 2004 Gtz Waschk <waschk@linux-mandrake.com> 1.3.0-3mdk
- depend on pyOpenSSL

* Wed Sep 22 2004 Michael Scherer <misc@mandrake.org> 1.3.0-2mdk 
- split the doc from main package
- fix url of source, and remoe unused macro

* Tue Aug 17 2004 Pascal Terjan <pterjan@mandrake.org> 1.3.0-1mdk
- New version

* Thu Apr 08 2004 Pascal Terjan <pterjan@mandrake.org> 1.2.0-1mdk
- New version
- Contains .so so can't be noarch
- BuildRequires python-devel

* Mon Dec 15 2003 Erwan Velu <erwan@mandrakesoft.com> 1.1.1-1mdk
- New version

* Mon Oct 27 2003 Han Boetes <han@linux-mandrake.com> 1.1.0-1mdk
- Bump

* Wed Oct 15 2003 Han Boetes <han@linux-mandrake.com> 1.0.7-1mdk
- Cleaned up the spec
- Changed architecture
- New version
- Known bug: conch doesn't work with openssh-3.7.1

* Wed Sep 17 2003 Han Boetes <han@linux-mandrake.com> 1.0.6-2mdk
- Added pycrypto-dependency. Now we can use conch as well.
- Removed trailing whitespace.

* Sun Aug 24 2003 Frederic Lepied <flepied@mandrakesoft.com> 1.0.6-1mdk
- initial Mandrake Linux packaging

